# include "Ximage.h"
# include "icons/icon.h"

/************** SetUpWindow *************/
void SetUpWindow (int *argc, char **argv) {

  int N;
  Icon icon;

  icon.width = icon_width;
  icon.height = icon_height;
  icon.bits = icon_bits;

  CheckGeometry (argc, argv);
  TopWindow (&icon);
  LoadFont (argc, argv, "fixed"); 

  FlushDisplay ();
  XSetWindowBackground (graphic.display, graphic.window, graphic.back);

  SetNormalHints ();
  SetWMHints (&icon);
  NameWindow ("Kapa");

  if ((N = get_argument (*argc, argv, "-nomap"))) {
    remove_argument(N, argc, argv);
  } else {
    MapWindow (graphic);
  }  
  
}
